@@ -27,12 +27,15 @@ class Params(params.Params):
 
 
 class Hyperparams(hyperparams.Hyperparams):
+    pass
+    '''
     n_bins = hyperparams.UniformInt(
                             lower=5,
                             upper=15,
                             default=10,
                             description='The maximum number of bins used for continuous variables discretization.'
                             )
+    '''
 
 
 class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
@@ -62,7 +65,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.17',
+        'version': '2.0.19',
         'name': 'IPCMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -71,7 +74,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         'installation':[{
             'type': 'PIP',
             'package': 'rpi_featureSelection_python_tools',
-	    'version': '2.0.17'
+	    'version': '2.0.19'
         }],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
         'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
@@ -105,7 +108,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         if self._training_inputs.any() == None or self._training_outputs.any() == None: 
             raise ValueError('Missing training data, or missing values exist.')
 
-        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs, 'hm_bins': hyperparams['n_bins']})
+        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
 
         a = rpi_feature_selection_toolbox.initialize()
         index = np.reshape(np.array(a.IPCMBplus()), [-1, ])
